//////////////////////////////////////////////////////////////
//      $Id: updateLoc.h,v 1.22 2003/03/04 15:20:47 toivo Exp $
//
// Author: Toivo Pedaste
//
#ifndef DEBLOCATE_H
#define DEBLOCATE_H

#include "../config.h"

// Standard Headers
#include <stdio.h>

// Qt Headers
#include <qdir.h>
#include <qwidget.h>
#include <qframe.h>
#include <qlabel.h>
#include <qfiledialog.h>
#include <qgroupbox.h>
#include <qcheckbox.h>
#include <qlayout.h>
#include <qlineedit.h>

// KDE headers
#include <kbuttonbox.h>
#include <kdialogbase.h>

class pkgInterface;
class updateLoc;
class cacheObj;
class LcacheObj;
class KComboBox;

//////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////
class dpanel : public QWidget
{
  Q_OBJECT

public:
  dpanel(QWidget *parent, const char * name  = 0);
  dpanel(dpanel *basep,  QString Pfilter,  bool bsubdirs,
	 QWidget *parent, const char * name = 0);
  ~dpanel();


  QString getText();
  void setText(QString s);
  bool getUse();
  void setUse(int n);
  bool getSubdirs();
  void setSubdirs(int n);

private:

  QCheckBox *psubdirs;
  QCheckBox *puse;
  QHBoxLayout* pack;
  QLineEdit *pent;
  QPushButton *pbut;

  dpanel *base;
  QString filter;

 public slots:
  void fileOpen();
  void dirOpen();

};

//////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////
class apanel : public QWidget
{
  Q_OBJECT

public:
  apanel( QWidget *parent, const char * name  = 0 );
  ~apanel();


  QString getText();
  void setText(QString s);
  bool getUse();
  void setUse(int n);
  void clear();

private:

  QCheckBox *puse;
  QHBoxLayout* pack;
  QLineEdit *pent;



 public slots:

};

//////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////
class updateLoc : public QWidget
{
  Q_OBJECT

public:

  updateLoc (QWidget *p, int panelNumber, pkgInterface *inter, QString iname);
  ~updateLoc();

  virtual void readSettings() = 0;
  virtual void writeSettings() = 0;

  virtual void applyS(LcacheObj *slist) = 0;

  void doBase(QString bmsg);

  QString interName;
  int panNumber;

  bool haveBase;

  pkgInterface *interface;

  QVBoxLayout *vf;
  dpanel *base;

  QGroupBox *fbase;
  QVBoxLayout* vbase;
};

//////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////
class aUpdateLoc : public updateLoc
{
  Q_OBJECT

public:

  aUpdateLoc (QWidget *p, int panelNumber, pkgInterface *inter, QString iname,
			 int numberLines, QString label);
  ~aUpdateLoc();


  void readSettings();
  void writeSettings();

  void applyS(LcacheObj *slist);

private:

   QString packL, packU, packS,  availB;
 
  int wdth;

  QPushButton  *butloc;

  QHBoxLayout* hloc;

  int numLines;
  enum { PNUM = 100 };
  apanel *ap[PNUM];

  QVBoxLayout* vl;
  QVBoxLayout* vtop;
  QGroupBox *frame1;
  KButtonBox* hb;

};

//////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////
class pdUpdateLoc : public updateLoc
{
  Q_OBJECT

public:

  pdUpdateLoc (QWidget *p, int panelNumber, pkgInterface *inter,
	       QString iname, int numberLines, QString filter, 
	       QString lmsg, QString bmsg = 0,
	       bool subdirs = FALSE);
  ~pdUpdateLoc();


  void readSettings();
  void writeSettings();

  void applyS(LcacheObj *slist);

private:

   QString packL, packU, packS,  availB;
 
  int wdth;

  QPushButton  *butloc;

  QHBoxLayout* hloc;

  int numLines;
  enum { PNUM = 40 };
  dpanel *dp[PNUM];

  QVBoxLayout* vl;
  QVBoxLayout* vtop;
  QGroupBox *frame1;
  KButtonBox* hb;

};

//////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////
class cUpdateLoc : public updateLoc
{
  Q_OBJECT

public:

  cUpdateLoc (QWidget *p, int panelNumber, pkgInterface *inter,
	      QString iname, int numberLines, QString baseMsg,
		       QString boxLabels, QString boxValues);
  ~cUpdateLoc();


  void readSettings();
  void writeSettings();

  void applyS(LcacheObj *slist);

private:

  QString  packC,  availB;

  QPushButton  *butloc;

  QHBoxLayout* hloc;

  int numLines;
  enum { PNUM = 40 };
  KComboBox *combo[PNUM];

  QVBoxLayout* vl;
  QVBoxLayout* vtop;
  QGroupBox *frame1;
  KButtonBox* hb;



};

//////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////

class Locations : public KDialogBase
{
  Q_OBJECT

public:
  Locations( QString msg);
  ~Locations();

  void dLocations(int numberDirs,  int numberLines,
		  pkgInterface *inter, QString iname,
		  QString label, QString filter, QString dirMsg,
		  bool subdirs=TRUE );

  void pLocations(int numberDirs,  int numberLines,
		  pkgInterface *inter, QString iname,
		  QString label, QString filter,
		  QString packMsg, QString baseMsg = 0,
		  bool subdirs=FALSE);

  void cLocations(int numberDirs, int numberLines,
		  pkgInterface *inter, QString iname, QString label,
		  QString filter,
		  QString boxLabels, QString baseMsg, QString boxValues);

  void aLocations(int numberDirs,   int numberLines,
		 pkgInterface *inter, QString iname, QString label);



  // bmsg indicates the panel has a base entry
  void restore();

  int numPanels;
  enum { PANNUM = 10 };
  updateLoc *pn[PANNUM];

public slots:
  void apply_slot();
  void write_slot();

signals:
  void returnVal(LcacheObj *);

};

//////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////

#endif
